# -*- coding: utf-8 -*-

import json
import urllib

from flask import redirect, url_for, request, current_app
from functools import wraps

def wxmp_login_required(func):
    @wraps(func)
    def decorated_view(*args, **kwargs):
        cookies_name = current_app.config.get("WXMP_USER_COOKIES_NAME")
        token_data = request.cookies.get(cookies_name)
        if not token_data:
            return redirect(url_for("wxmp.wxmp_login", next=request.path))
        kwargs.update({"token_data": json.loads(token_data)})
        return func(*args, **kwargs)
    return decorated_view

def wxmp_base_login_required(func):
    @wraps(func)
    def decorated_view(*args, **kwargs):
        cookies_name = current_app.config.get("WXMP_BASE_COOKIES_NAME")
        token_data = request.cookies.get(cookies_name)
        if not token_data:
            return redirect(
                url_for(
                    "wxmp.wxmp_login", 
                    next="?".join([
                        request.path, 
                        urllib.parse.urlencode(request.args)
                    ]),
                    oauth_type="snsapi_base")
            )
        kwargs.update({"token_data": json.loads(token_data)})
        return func(*args, **kwargs)
    return decorated_view
